@@ -137,9 +137,8 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.099_03';
+our $VERSION = '0.099_04';
 
-use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
 use POSIX qw{floor strftime};	# For debugging
@@ -251,12 +250,6 @@ foreach my $mma (0 .. 2) {
 my @inverse_transform_vector =
     map {scalar _invert_matrix_list (@$_)} @transform_vector;
 
-
-#	Various things we will share.
-
-my $sun;	# For an Astro::Coord::ECI::Sun object.
-
-
 =item $tle->after_reblessing (\%attribs);
 
 This method supports reblessing into a subclass, with the argument
@@ -551,7 +544,7 @@ eod
     my $illum = $self->get ('illum');
     my $horizon = $self->get ('horizon');
     my $twilight = $self->get ('twilight');
-    $sun ||= Astro::Coord::ECI::Sun->new ();
+    my $sun = $self->get( 'sun' );
 
     my %want = (
 	am => $self->get ('am'),
@@ -1063,7 +1056,7 @@ my $height = ($station->geodetic)[2];
 
 #	And any odds and ends we might need.
 
-$sun ||= Astro::Coord::ECI::Sun->new ();
+my $sun = $self->get( 'sun' );
 my $twilight = $self->get ('twilight');
 my $atm_extinct = $self->get ('extinction');
 
@@ -1688,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sat Jul  7 12:50:38 2018 GMT
+# on Wed Jul 11 13:36:26 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1764,7 +1757,7 @@ __PACKAGE__->status( add => 25342, iridium => '+', 'Iridium 70', '' );
 __PACKAGE__->status( add => 25343, iridium => 'D', 'Iridium 72', 'Decayed 2018-05-14' );
 __PACKAGE__->status( add => 25344, iridium => '-', 'Iridium 73', 'Tumbling' );
 __PACKAGE__->status( add => 25345, iridium => 'D', 'Iridium 74', 'Decayed 2017-06-11' );
-__PACKAGE__->status( add => 25346, iridium => '-', 'Iridium 75', 'Tumbling' );
+__PACKAGE__->status( add => 25346, iridium => 'D', 'Iridium 75', 'Decayed 2018-07-10' );
 __PACKAGE__->status( add => 25431, iridium => 'D', 'Iridium 3', 'Decayed 2018-02-08' );
 __PACKAGE__->status( add => 25432, iridium => 'S', 'Iridium 76', '' );
 __PACKAGE__->status( add => 25467, iridium => '-', 'Iridium 82', 'Tumbling' );
@@ -1792,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => 'S', 'Iridium 98', '' );
 # Summary:
 # Operational [+]: 18
 #       Spare [S]: 16
-#    Tumbling [-]: 39
-#     Decayed [D]: 24
+#    Tumbling [-]: 38
+#     Decayed [D]: 25
 
 1;
 
